

proc format;
	value visf
    1 = "Baseline"
    2 = "Treatment P1 - Day 10"
    3 = "Treatment P2 - Day 17"
	4 = "Treatment P2 - Day 24"
    5 = "Treatment P2 - Day 31"
    6 = "Treatment P2 - Day 52"
    7 = "Treatment P2 - Day 73"
    8 = "Treatment P2 - Day 94"
;
run;

proc sql noprint;
   select count(USUBJID) into :T1 from ADAM.adsl where SAFFL = "Y" & group01  ="Normal";
   select count(USUBJID) into :T2 from adam.adsl where SAFFL = "Y" & group01  ="Severe";
Quit;


options nobyline nodate nonumber orientation = landscape;
ods listing close;
/*ods _ALL_ close;*/
filename rtf "&Root.\Outputs\figures\LBF1.rtf";

ods rtf file=rtf bodytitle_aux ;


%macro dofig(lbtestcd=,figfile=, num =, min =, max =, step =);


footnote;
title;


/* check visits included in the data */
proc sort data=adam.adlb out=test(keep=avisitn avisit ablfl) nodupkey;
	by avisitn avisit ablfl;
	where (SAFFL = "Y" and LBCAT in("HEMATOLOGY") and ANL01FL = "Y" );
run;


/*Get the lab data*/
data lab ;
	set adam.adlb;
	where (SAFFL = "Y" and LBCAT in("HEMATOLOGY") and ANL01FL = "Y" );
  
	if ABLFL = "Y" then do;
		AVISIT = "Baseline";
		AVISITN = 1;
	end;
	else if AVISIT='Treatment P1 - Day 10' then AVISITN=2;
	else if AVISIT='Treatment P2 - Day 17' then AVISITN=3;
	else if AVISIT='Treatment P2 - Day 24' then AVISITN=4;
	else if AVISIT='Treatment P2 - Day 31' then AVISITN=5;
	else if AVISIT='Treatment P2 - Day 52' then AVISITN=6;
	else if AVISIT='Treatment P2 - Day 73' then AVISITN=7;
	else if AVISIT='Treatment P2 - Day 94' then AVISITN=8;
	else delete;
run;


data LAB1;
	set LAB;
   if upcase(LBTEST) = "HEMOGLOBIN" then sort = 1;
   else if upcase(LBTEST) = "ERYTHROCYTES"  then sort = 2;
   else if upcase(LBTEST) = "HEMATOCRIT"  then sort = 3;
   else if upcase(LBTEST) = "LEUKOCYTES" then sort = 4;
   else if upcase(LBTEST) = "BASOPHILS" then sort = 6;
   else if upcase(LBTEST) = "EOSINOPHILS" then sort = 7;
   else if upcase(LBTEST) = "MONOCYTES" then sort = 8;
   else if upcase(LBTEST) = "LYMPHOCYTES" then sort = 9;
   else if upcase(LBTEST) = "NEUTROPHILS" then sort = 10;
   else if upcase(LBTEST) = "PLATELETS" then sort = 11;
   else if upcase(LBTEST) = "RETICULOCYTES" then sort = 12;


   else if upcase(LBTEST) = "ACTIVATED PARTIAL THROMBOPLASTIN TIME" then sort = 13;
   else if upcase(LBTEST) = "PROTHROMBIN INTL. NORMALIZED RATIO" then sort = 14;

   else if upcase(LBTEST) = "ALANINE AMINOTRANSFERASE" then sort = 202;
   else if upcase(LBTEST) = "ASPARTATE AMINOTRANSFERASE" then sort = 203;
   else if upcase(LBTEST) = "ALKALINE PHOSPHATASE" then sort = 204;
   else if upcase(LBTEST) = "ALBUMIN" then sort = 205;
   else if upcase(LBTEST) = "BILIRUBIN" then sort = 206;
   else if upcase(LBTEST) = "CALCIUM" then sort = 207;
   else if upcase(LBTEST) = "SODIUM" then sort = 208;
   else if upcase(LBTEST) = "POTASSIUM" then sort = 209;
   else if upcase(LBTEST) = "MAGNESIUM" then sort = 210;
   else if upcase(LBTEST) = "GLUCOSE" then sort = 211;
   else if upcase(LBTEST) = "BLOOD UREA NITROGEN" then sort = 212;
   else if upcase(LBTEST) = "CREATININE" then sort = 213;
   else if upcase(LBTEST) = "LACTATE DEHYDROGENASE" then sort = 214;
   else delete;
   AVISIT  = tranwrd(AVISIT,"Period","TP");
   PARAM=tranwrd(PARAM,"Leucocytes","Leukocytes");
   PARAM=tranwrd(PARAM,'"','');
   
run;

proc sort;
  by AVISITN AVISIT PARAM PARAMCD AVAL;
  where LBCAT in ("HEMATOLOGY");
run;


data lb1;
	set lab1;
	where lbtestcd eq &lbtestcd;
	c=1;
run;


proc sort data=lb1 out=temp nodupkey; by USUBJID;
run;


data template(keep=USUBJID AVISITN);
	set temp;
	do i = 1 to 8;
		AVISITN=i;
		output;
	end;
run;


proc sort; by USUBJID AVISITN;
run;


proc sort data=lb1; by USUBJID AVISITN;
run;


data lb2;
	merge lb1(in=x) template(in=y);
	by USUBJID AVISITN;	
run;


data _null_;
  set lb1;
  /*VAriable to hold the lab test name*/
  call symputx('vlabel',param);
  if ^missing(A1LON) then call symputx('vrefl',A1LON);
  else if ^missing(ANRLO) then  call symputx('vrefl',ANRLO);
  else if ^missing(LBSTNRLO) then  call symputx('vrefl',LBSTNRLO);
  
  if ^missing(A1HIN) then call symputx('vrefh',A1HIN);
  else if ^missing(ANRHI) then  call symputx('vrefh',ANRHI);
  else if ^missing(LBSTNRHI) then  call symputx('vrefh',LBSTNRHI);
run;

%put &vlabel &vrefl &vrefh;

proc sort data=lb1;
    by c AVISITN;

 *** Put maximum/minimum ranges into macro variables ***;
proc means data=lb1 noprint;
    var aval;
	by c;
    output out=rngstat
    min=min
    max=max;
run;


data rngstat;
    set rngstat;
    if &vrefl ne . and &vrefl lt min then min = &vrefl;
    if &vrefh ne . and &vrefh gt max then max = &vrefh;
run;


data _null_;
    set rngstat nobs = N;
	call symputx("N",N);
    call symputx('minc'||strip(put(_n_,best.)),min);
    call symputx('maxc'||strip(put(_n_,best.)),max);
run;


%macro checking;
%do i = 1 %to &N;
%put MINC&i.=&&minc&i;
%put MAXC&i.=&&maxc&i;
%end;
%mend;

%checking;


proc sort data=lb1; by group01 avisitn;
run;


proc means data=lb1(where=(^missing(aval))) noprint;
    by group01 AVISITN;
    var aval;
    output out=ncount
    n=COUNT;
run;


**Creat output and show N = 0 if no visit;
data shellN;
	group01='Normal';	
		do i=1 to 2;
			avisitn = i;
			output;
		end;
		group01='Severe';	
		do i=1 to 8;
			avisitn = i;
			output;
		end;
run;


proc sort data = shellN; by group01 avisitn;
run;


data ncount;
   	merge ncount shellN;
	by group01 avisitn;
run;


data _null;
    set ncount;
	if missing(COUNT) then COUNT = 0;
	call  symputx('n_'||strip(put(avisitn,2.))||'_'||strip(group01),count);
run;


data maxx; 
    set rngstat;
    if 0<abs(max)<=1 then do;
      maxx=round(max,0.1);
      if maxx<max then maxx=maxx+0.1;
      call symputx('step',0.1);
	  step = 0.1;
    end;  
    else if 1<abs(max)<=10 then do;
      maxx=round(ceil(max),1);                            
      call symputx('step',1);
	  step = 1;
    end;  
    else if 10<abs(max)<=100 then do;
      maxx=round(max,10);
      if maxx<max then maxx=maxx+10;
      call symputx('step',10);
	  step = 10;
    end; 
    else if 100<abs(max)<=200 then do;
      maxx=round(max,20);
      if maxx<max then maxx=maxx+20;
      call symputx('step',20);
	  step = 20;
    end;
    else if 200<abs(max)<=1000 then do;
      maxx=round(max,100);
      if maxx<max then maxx=maxx+100;
      call symputx('step',100);
	  step = 100;
    end;
    else if 1000<abs(max)<=3000 then do;
      maxx=round(max,200);
      if maxx<max then maxx=maxx+200;
      call symputx('step',200);
	  step = 200;
    end ;
    call symputx('maxc',max);
    call symputx('maxax',maxx);
    call symputx('maxax2',maxx);
run;

%put &maxax ;

data _null_;
    set maxx;
    if step=0.1 then do;
      temp=round(min,0.1);
      if temp>min then temp=temp-0.1;
    end;
    else if step=1 then do;
      temp=round(min,1);
      if temp>min then temp=temp-1;
    end;
    else if step=10 then do;
      temp=round(min,10);
      if temp>min then temp=temp-10;
    end;
    else if step=20 then do;
      temp=round(min,20);
      if temp>min then temp=temp-20;
    end;
    else if step=100 then do;
      temp=round(min,100);
      if temp>min then temp=temp-100;
    end;
    else if step=200 then do;
      temp=round(min,200);
      if temp>min then temp=temp-200;
    end;
    call symputx('minax',temp);

run;

%put &minax ;


data _null_;
  nowd=put(date(),date9.);
  nowt=put(time(),time5.);
  call symput('nowd',nowd);
  call symput('nowt',nowt);
run;    


%do i = 1 %to &N %by 1; 

data _NULL_;
	I = symgetN('i');
	_page = I;
	_PAGE=&num;

	call symputX('page',_page);
run;


ods rtf select none;


GOPTIONS DEVICE=PNG TARGETDEVICE=PNG
         XMAX=5in YMAX=4.5in XPIXELS=1500 YPIXELS=1350 HSIZE=5in VSIZE=4.5in 
         FTEXT="Arial" HTEXT=8pt HBY=0 HTITLE=10pt CPATTERN=GREY;


axis1 offset=(1,1) 
      label=(j=c h=6pt font="Arial/bold" " " )
	  value=(h=6pt font="Arial/bold")
      minor=none
	  %if &lbtestcd. = "RBC" %then %do ;
		order = 2 to 12 by  2 ; 
%end ;
 %else %if &lbtestcd. = "EOS" %then %do ;
		order = 0 to 1.5 by  0.5 ; 
%end ;
%else %if &lbtestcd. = "HCT" %then %do ;
		order = 0.25 to 0.55 by  0.1 ; 
%end ;
  %else %do ;
		order=&minax to &maxax by &step; 
%end ;
      
	  
axis2 offset=(15,15)
      order= (1 to 2 by 1) minor=none 
      value=(
             t=1 h=5pt font="Arial/bold" j=c "Baseline" h=6pt font="Arial/bold"  j=c "(N=&n_1_normal)"
             t=2 h=5pt font="Arial/bold" j=c "TP1 Day 10" h=6pt font="Arial/bold"  j=c "(N=&n_2_normal)"
			)
      label=(j=c font="Arial/bold" h=8pt "Timepoints") 
   	  ;
axis3 offset=(1,1) 
      label=(j=c h=6pt font="Arial/bold" " " )
	  value=(h=6pt font="Arial/bold")
      minor=none
	  %if &lbtestcd. = "RBC" %then %do ;
		order = 2 to 12 by  2 ; 
%end ;
 %else %if &lbtestcd. = "EOS" %then %do ;
		order = 0 to 1.5 by  0.5 ; 
%end ;
%else %if &lbtestcd. = "HCT" %then %do ;
		order = 0.25 to 0.55 by  0.1 ; 
%end ;
  %else %do ;
		order=&minax to &maxax by &step; 
%end ;
	   
axis4 offset=(5,5)
      order=(1 to 8 by 1) 
      value=(
             t=1 h=5pt font="Arial/bold" j=c "Baseline"   h=6pt font="Arial/bold"  j=c "(N=&n_1_severe)"
             t=2 h=5pt font="Arial/bold" j=c "TP1 Day 10" h=6pt font="Arial/bold"  j=c "(N=&n_2_severe)"
             t=3 h=5pt font="Arial/bold" j=c "TP2 Day 17" h=6pt font="Arial/bold"  j=c "(N=&n_3_severe)"
			 t=4 h=5pt font="Arial/bold" j=c "TP2 Day 24" h=6pt font="Arial/bold"  j=c "(N=&n_4_severe)"
			 t=5 h=5pt font="Arial/bold" j=c "TP2 Day 31" h=6pt font="Arial/bold"  j=c "(N=&n_5_severe)"
			 t=6 h=5pt font="Arial/bold" j=c "TP2 Day 52" h=6pt font="Arial/bold"  j=c "(N=&n_6_severe)"
             t=7 h=5pt font="Arial/bold" j=c "TP2 Day 73" h=6pt font="Arial/bold"  j=c "(N=&n_7_severe)"
             t=8 h=5pt font="Arial/bold" j=c "TP2 Day 94" h=6pt font="Arial/bold"  j=c "(N=&n_8_severe)"
			 )
      label=(j=c font="Arial/bold" h=8pt "Timepoints") 
   ;



ods graphics off;

data lb2;
	set lb2;
	format avisitn visf.;
	label AVISITN = "Timepoints";
run;


proc sort data=lb2; by group01 AVISITN;
run;


data lb2;
   	merge ncount lb2;
	by group01 avisitn;
run;


data lb2;
	set lb2;
	if count <= 1 then aval=.;
run;


proc sort data=lb2; by group01;
run;





/*title "Group: Normal renal function"; */
proc boxplot data = lb2 gout=work.graph;
  plot aval*avisitn /   boxstyle = schematic  haxis=axis2 vaxis=axis1 lvref=2 vref=&vrefl, &vrefh BOXWIDTH=1;
  where group01='Normal';
run;


/*title "Group: Severe renal impairment";*/
proc boxplot data = lb2 gout=work.graph;
  plot aval*avisitn /   boxstyle = schematic  haxis=axis4 vaxis=axis3 lvref=2 vref=&vrefl, &vrefh BOXWIDTH=1;
  where group01='Severe'; 
run;



GOPTIONS DEVICE=PNG TARGETDEVICE=PNG
         XMAX=9in YMAX=6.5in XPIXELS=2700 YPIXELS=1950 HSIZE=9in VSIZE=4.5in 
         FTEXT="Arial" HTEXT=8pt HBY=0 HTITLE=8pt CPATTERN=GREY;


proc gslide gout=work.graph;
  title1 h=8pt j=c F="Arial" "XYZ";
  %if &lbtestcd. = "HCT" %then %do ; 
	title2 h=8pt j=c F="Arial" "LBF1  Haematology laboratory data, box plot of Hematocrit ratio values (Safety analysis set)";
%end ;
%else %do ;
	title2 h=8pt j=c F="Arial" "LBF1  Haematology laboratory data, box plot of &vlabel absolute values (Safety analysis set)";
%end ;

title5 "Group: Normal renal function (N=%qcmpres(&T1.))                                                                                                             Group: Severe renal function (N=%qcmpres(&T2.))";


  footnote1 h=8pt J=C F="Arial" " ";
  footnote2 h=8pt J=C F="Arial" " ";
  footnote3 h=8pt J=R F="Arial" "PAGE &num. OF 11";
  footnote5 h=8pt J=L F="Arial" "Horizontal line : Median,  Cross: Mean, Box : Q1 - Q3.";
  footnote6 h=8pt J=L F="Arial" "Whiskers extend to the most extreme observation within 1.5 times the interquartile range from the ";
  footnote7 h=8pt J=L F="Arial" "nearest quartile, so that all outliers >1.5 times the interquartile range are individually displayed as white squares."; 
  footnote8 h=8pt J=L F="Arial" " ";
run;

proc greplay tc=work.tempcat nofs;
tdef newtemp des='Two panel template'
1/ulx=0 uly=100
urx=100 ury=100
llx=0 lly=0
lrx=100 lry=0

2/ulx=0 uly=90
urx=50 ury=90
llx=0 lly=20
lrx=50 lry=20

3/ulx=50 uly=90
urx=100 ury=90
llx=50 lly=20
lrx=100 lry=20

;
ods rtf select all;

proc greplay igout=graph gout=excat tc=tempcat nofs;
   template=newtemp;

   treplay 
   		   1:gslide
           2:boxplot 
           3:boxplot1;
   delete _all_;
         quit;

footnote;
title;
%end;


%mend dofig;
%dofig(lbtestcd = "HGB",figfile=LBF1.rtf , num = 1,min=10,max=180,step=10); 
%dofig(lbtestcd = "HCT",figfile=LBF1.rtf , num = 2,min=0,max=44,step=4); 
%dofig(lbtestcd = "RBC",figfile=LBF1.rtf , num = 3,min=2,max=7,step=1);
%dofig(lbtestcd = "RETI",figfile=LBF1.rtf, num = 4,min=0,max=120,step=10); 
%dofig(lbtestcd = "WBC",figfile=LBF1.rtf , num = 5,min=0,max=40,step=5); 
%dofig(lbtestcd = "BASO",figfile=LBF1.rtf, num = 6,min=0,max=0.25,step=0.05);
%dofig(lbtestcd = "EOS",figfile=LBF1.rtf , num = 7,min=0,max=1.8,step=0.1);
%dofig(lbtestcd = "MONO",figfile=LBF1.rtf, num = 8,min=0,max=3,step=0.5); 
%dofig(lbtestcd = "LYM",figfile=LBF1.rtf , num = 9,min=0,max=5,step=0.5); 
%dofig(lbtestcd = "NEUT",figfile=LBF1.rtf, num = 10,min=0,max=40,step=5); 
%dofig(lbtestcd = "PLAT",figfile=LBF1.rtf, num = 11,min=0,max=600,step=60); 
ods rtf close;
