

options missing='';


**----------------------------------------------------**;
** Read in required data                              **;
** anl03fl flags maximum                **;
**----------------------------------------------------**;
/*Get the lab data*/
data lb33;*(keep=SUBJID AVISITN AVISIT PARAM PARAMCD AVAL);
  set adam.adlb;
  where SAFFL eq "Y" and CRIT1FL eq "Y" and LBTESTCD in ("ALT","BILI") and LBCAT='CHEMISTRY';
  if ^missing(A1HI) and ^missing(AVAL) then R2ANRHI = AVAL/(input(A1HI,$6.));
  PARAMCD = LBTESTCD;
  proc sort;
  by  USUBJID ;
run;



**----------------------------------------------------------**;
** Manipulate data to get ALT/ALT and bilirubin on same row **;
** Only want to keep subjects with both parameters          **;
**----------------------------------------------------------**;
data lba (rename=(paramcd=testcd1 R2ANRHI=plotvarx) );
  set lb33;
  where paramcd in ('ALT');
run;

data lbb (rename=(paramcd=testcd2 R2ANRHI=plotvary) );
  set lb33;
  where paramcd in ('BILI');
run; 
 
proc sql;
  create table lb1 as
  select distinct a.*, b.testcd2, b.plotvary
  from lba as a left join lbb as b
  on a.usubjid=b.usubjid
  and a.APERIOD=b.APERIOD
  where not missing (a.plotvarx) and not missing(b.plotvary)
  order by plotvary;
quit;

data lb2;
	set lb1;

data _null_;
  nowd=put(date(),date9.);
  nowt=put(time(),time5.);
  call symput('nowd',nowd);
  call symput('nowt',nowt);
run;    


%let cntr=0;
data _NULL_;
	set lb2;
	call symputx('cntr',_N_);
run;
%put &cntr;
%MACRO REP;
**-----------------------------**;
** Set output options          **;
**-----------------------------**;
ods listing close;
ods graphics on / reset=all imagename="lbf2" imagefmt=png border=on;
ods listing style=analysis gpath="&Root.\Outputs\figures\";

ods path work.templat (write)
  sasuser.templat (update)
  sashelp.tmplmst (read);

title;
footnote;

filename figout "&Root.\Outputs\figures\LBF2.rtf";

options papersize = a4 orientation=landscape nodate nonumber 
  topmargin=1in
  bottommargin=0.5in
  leftmargin=0.25in
  rightmargin=0.25in ;

goptions reset=all device=png targetdevice=png vsize=6 hsize=9 goutmode=replace rotate=landscape gunit=pct 
  gsfmode=replace ftext="Arial" XMAX=9in YMAX=6in XPIXELS=2700 YPIXELS=1800 HTEXT=8pt HTITLE=10pt ;

ods rtf file=figout bodytitle headery=770 footery=770  style=rtf;
  ods rtf gfootnote gtitle;
  ods graphics / height=6in width=9in border=off ;
  ods nousegopt;

**---------------------------------------------**;
** Create output template and output figure    **;
**---------------------------------------------**;
%if &cntr=0 %then %do;
data LB2;
	plotvarx=101;plotvary=101;
	output;
run;

	proc template;
	  define statgraph SAFF5;
	    begingraph;
	      entrytitle halign=center "XYZ" / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	      entrytitle halign=center "Figure LBF2 ALT versus total bilirubin, expressed as multiples of ULN" / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	      entrytitle halign=center "(Safety analysis set)" / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	      entrytitle " " / textattrs=(family="Arial" size=8pt /*weight = bold*/);
		  entryfootnote halign=center "Maximum post-baseline ALT (multiples of ULN)" / textattrs=(family="Arial" size=8pt /*weight = bold*/);
      entrytitle " " / textattrs=(family="Arial" size=8pt /*weight = bold*/);
      entrytitle " " / textattrs=(family="Arial" size=8pt /*weight = bold*/);
      entrytitle " " / textattrs=(family="Arial" size=8pt /*weight = bold*/);
      entrytitle " " / textattrs=(family="Arial" size=8pt /*weight = bold*/);
      entrytitle "No data meeting criteria." / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	  entryfootnote halign=center " " / textattrs=(family="Arial" size=8pt /*weight = bold*/);
		  entryfootnote halign=right "PAGE 1 OF 1" / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	      entryfootnote halign=left "ALT  Alanine aminotransferase.  ULN  Upper limit of normal.  " / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	      entryfootnote halign=left " " / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	      layout 
	        lattice / 
	          columns=1 columnweights=(1) columngutter=0 rowdatarange=union;
	            layout  overlay / border = false
	                xaxisopts = (type=log/*label="Maximum post-baseline ALT (multiples of ULN)" */ label = " "
	                  labelattrs=(family="Arial" size=0pt weight = bold )
	                  tickvalueattrs=(family="Arial" size=8pt /*weight = bold*/)
	                    logopts = (base=10 tickintervalstyle=logexpand minorticks=false viewmin=0.01 viewmax=10))
	                yaxisopts = (type=log label="Max. post-baseline BILI (multiples of ULN)" 
	                  labelattrs=(family="Arial" size=8pt /*weight = bold*/) 
	                  tickvalueattrs=(family="Arial" size=8pt /*weight = bold*/)
	                    logopts = (base=10 tickintervalstyle=logexpand minorticks=false viewmin=0.1 viewmax=10));
	                entry  halign=center " " / pad=(right=2.75%) location=outside valign=top 
	                  textattrs=(family="Arial" size=8pt /*weight = bold*/);
	                scatterplot x = plotvarx y = plotvary /  markerattrs = (color=black symbol=circlefilled size=4) 
	                  name="Plot";
	                      referenceline y=2;
	                      referenceline x=3;
	            endlayout;
	      endlayout;
	    endgraph;
	  end;
	run;

	proc sgrender data=lb2 template=SAFF5;
	run;

proc sgrender data=lb2 /*SGANNO=non*/ template=SAFF5;
run;

%end;
%else %do;
data lb2 ;
	set lb2 ;
	*where APERIODC in ("Part A" "Part B");
	if APERIODC = "Part A" then  do ;
		plotvarx_A = plotvarx ; 
		plotvary_A = plotvary ;
	End ;
	if APERIODC = "Part B" then  do ;
		plotvarx_B = plotvarx ; 
		plotvary_B = plotvary ;
	End ;
Run ;
	proc template;
	  define statgraph SAFF5;
	    begingraph;
	      entrytitle halign=center "XYZ" / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	      entrytitle halign=center "Figure LBF2 ALT versus total bilirubin, expressed as multiples of ULN" / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	      entrytitle halign=center "(Safety analysis set)" / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	      entrytitle " " / textattrs=(family="Arial" size=8pt /*weight = bold*/);
		  entrytitle halign=left "                                                                PART A                              
							                                                                      PART B" / textattrs=(family="Arial" size=8pt /*weight = bold*/);
		  *entryfootnote halign=center "Maximum post-baseline ALT (multiples of ULN)" / textattrs=(family="Arial" size=8pt /*weight = bold*/);
		  entryfootnote halign=center " " / textattrs=(family="Arial" size=8pt /*weight = bold*/);
		  entryfootnote halign=right "PAGE 1 OF 1" / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	      entryfootnote halign=left "ALT  Alanine aminotransferase.  ULN  Upper limit of normal.  " / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	      entryfootnote halign=left " " / textattrs=(family="Arial" size=8pt /*weight = bold*/);
	      layout 
	        lattice  / rows = 1 
	          columns=2 /*columnweights=(1)*/ columngutter=30 rowdatarange=union ;
	            layout   overlay / border = false
	                xaxisopts = (type=log label="Maximum post-baseline ALT (multiples of ULN)"  /*label = " "*/
	                  labelattrs=(family="Arial" size=8pt /*weight = bold*/ )
	                  tickvalueattrs=(family="Arial" size=8pt /*weight = bold*/)
	                    logopts = (base=10 tickintervalstyle=logexpand minorticks=false viewmin=0.01 viewmax=10))
	                yaxisopts = (type=log label="Max. post-baseline BILI (multiples of ULN)" 
	                  labelattrs=(family="Arial" size=8pt /*weight = bold*/) 
	                  tickvalueattrs=(family="Arial" size=8pt /*weight = bold*/)
	                    logopts = (base=10 tickintervalstyle=logexpand minorticks=false viewmin=0.1 viewmax=10));
	                entry  halign=center " " / pad=(right=2.75%) location=outside valign=top 
	                  textattrs=(family="Arial" size=8pt /*weight = bold*/);

               scatterplot x = plotvarx_A y = plotvary_A /  group = group01  /*markerattrs = (color=black symbol=TriangleFilled size=4)*/ 
	                  name="scatter" datalabel=name;
      					discretelegend "scatter" ;
	                      referenceline y=2;
	                      referenceline x=3;
	            endlayout;
layout   overlay / border = false
	                xaxisopts = (type=log label="Maximum post-baseline ALT (multiples of ULN)"  /*label = " "*/
	                  labelattrs=(family="Arial" size=8pt /*weight = bold*/ )
	                  tickvalueattrs=(family="Arial" size=8pt /*weight = bold*/)
	                    logopts = (base=10 tickintervalstyle=logexpand minorticks=false viewmin=0.01 viewmax=10))
	                yaxisopts = (type=log label="Max. post-baseline BILI (multiples of ULN)" 
	                  labelattrs=(family="Arial" size=8pt /*weight = bold*/) 
	                  tickvalueattrs=(family="Arial" size=8pt /*weight = bold*/)
	                    logopts = (base=10 tickintervalstyle=logexpand minorticks=false viewmin=0.1 viewmax=10));
	                entry  halign=center " " / pad=(right=2.75%) location=outside valign=top 
	                  textattrs=(family="Arial" size=8pt /*weight = bold*/);

               scatterplot x = plotvarx_B y = plotvary_B /  group = group01  /*markerattrs = (color=black symbol=TriangleFilled size=4)*/ 
	                  name="scatter" datalabel=name;
      					discretelegend "scatter" ;
	                      referenceline y=2;
	                      referenceline x=3;
	            endlayout;
	      endlayout;
	    endgraph;
	  end;
	run;

	proc sgrender data=lb2 template=SAFF5;
	*where APERIODC in ("Part A" "Part B");
	run;
%end;
%mend REP;
%rep;
ods rtf close;
ods listing;

