

/*******************************************
    Deleting data sets from work library 
*******************************************/

Proc Datasets library = work memtype = data nolist kill ;run ; quit ;


Data AE100_TEMP ;
  Length var1 - var11 SEX_ AEACN_  AEEVNT02_  AEOUT_ APHASE_ $200 ;
  Set ADAM.AE ;

  Where SAFFL = "Y" ;

 if PREFL="Y" then APHASE_='Pre-trt';
 else if TRTEMAFL="Y" then APHASE_='On-trt (A)';
 else if TRTEMBFL="Y" then APHASE_='On-trt (B)'; 

  Var1 = Strip(GROUP01) || "/" || Strip(APHASE_) ;

  Var2 = Strip(SUBJID) ;

  If SEX = "M" then SEX_ = "Male" ;
  If SEX = "F" then SEX_ = "Female" ; 

  Var3 = Strip(put(AGE , 6.)) || "/" || strip(SEX_) || "/" || strip(RACE) ;

  var4 = Strip(AEBODSYS) || "/" || Strip(AEDECOD) || "/" || strip(AETERM) ;  

  Var5 = Strip(put(AESTDY , 6.)) || "/" || Strip(put(ADURN , 6.)) ;
  If AESTDY = . and ADURN = . then Var5 = " " ;  

  var6 = Strip(AETOXGR);

  Var7 = Strip(AAE003FL) ;

  if AEACN = "DOSE NOT CHANGED" then AEACN_ = "DNC";
  else if AEACN = "NOT APPLICABLE" then AEACN_ = "NA";
  else if AEACN = "DRUG INTERRUPTED" then AEACN_ = "DINT";
  else if AEACN = "DRUG WITHDRAWN" then AEACN_ = "DPC";
  else if AEACN = "DOSE REDUCED" then AEACN_ = "DR";

  var8 = Strip(AEACN_) ;

  If AEEVNT02 = "Y" then AEEVNT02_ = "Yes" ;
  Else if AEEVNT02 = "N" then AEEVNT02_ = "No" ;

  Var9 = Strip(AEEVNT02_);

  Var10 = Strip(put(DOSEON , 6.)) || " " || strip(DOSAEONU) ;
  If Var10 = " " then var10 = "NA" ;

  If AEOUT in ("RECOVERED/RESOLVED" "RECOVERED/RESOLVED WITH SEQUELAE") then AEOUT_  = "RECOVRD";
  Else if AEOUT = "NOT RECOVERED/NOT RESOLVED" then AEOUT_  = "NRNR";
  Else if AEOUT = "RECOVERING/RESOLVING" then AEOUT_  = "RECVRNG";
  Else if AEOUT = "Recovered / Resolved" then AEOUT_  = "RWS";
  Else if AEOUT = "Fatal" then AEOUT_  = "F";

  Var11 = Strip(AEOUT_) || "/" || Strip(AECONTRT) ; 

    Proc sort ; by SUBJID AESTDY AEDECOD ;

Run ;

%LET EscapeChar=�;
Ods  EscapeChar="&EscapeChar."; 

/******setting _page break*****/

data AE100_TEMP ;
  Set AE100_TEMP ;
  Var1 = Strip(GROUP01) || "/&escapechar.n" || Strip(APHASE_) ;
  Var3 = Strip(put(AGE , 6.)) || "/" || strip(SEX_) || "/&escapechar.n" || strip(RACE) ;
  var4 = Strip(AEBODSYS) || "/&escapechar.n" || Strip(AEDECOD) || "/&escapechar.n" || strip(AETERM) ;
  var11 = Strip(AEOUT_) || "/&escapechar.n" || Strip(AECONTRT) ;  
run ;

Data AE100;
  set AE100_TEMP  end = eof;

   by SUBJID ;
   retain _page 1;
   cnt + 1;
   if cnt >= 3 then do;
    _page = _page + 1;
    cnt = .;
   end;
   breaklines = _n_;
   
   if eof then call symputx("totpages",_page);  
  
run;




/***Creating output rtf file***/

 
ods listing close;


options orientation=landscape topmargin=1.2in bottommargin=1in leftmargin=1in rightmargin=1in nodate nobyline; /*Adjusting the paper*/
ods rtf file= "&root./Outputs/Listings/AEL1.rtf" /*bodytitle*/;
title1    justify = center   height = 11pt  font = 'Arial' "XYZ";
title2    justify = center   height = 11pt  font = 'Arial' "Appendix 1 - Adverse events (Safety analysis set)";


proc report data=AE100  nowindows headline headskip split='*'
	style(report)=[background=white rules=NONE frame=void bordertopwidth=2]
	style(header)=[vjust = middle background=white font_face='Arial' font_size=9pt ]
	style(column)=[cellheight=0.6 in];

  By _page ;

  column _page SUBJID var1 var2 var3 var4  var5  var6 var7 var8 var9 Var10 Var11   ;

    define _page / order noprint;
    define SUBJID / order noprint;

  	define var1   / order flow  "Group [a]/*Phase [b]" flow style(column)=[cellwidth=0.65in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.65in   just=left  borderbottomcolor=black borderbottomwidth=2];
 
    define var2   /order  flow  "Subject*identifier" flow style(column)=[cellwidth=0.65in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.65in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define var3   /  flow "Age/Sex/*Race" style(column)=[cellwidth=0.65in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.65in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define var4   / order  flow "System organ class/*MedDRA preferred term/*VERBATIM TEXT" style(column)=[cellwidth=1.2in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=1.2in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define var5   /  flow "Study day*of start *of AE/*Duration of*AE (days)" style(column)=[cellwidth=0.75in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.75in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define var6   /  flow "Maximum*CTCAE*grade" style(column)=[cellwidth=0.75in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.75in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define var7   /   flow "Serious" style(column)=[cellwidth=0.65in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.65in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define var8   /  flow "Action taken*dummy [c]" style(column)=[cellwidth=0.85in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.85in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define var9   /  flow "Caused by*dummy [d]" style(column)=[cellwidth=0.78in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.78in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define var10   /  flow "Total Dose at*time of AE*dummy" style(column)=[cellwidth=0.85in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.85in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define var11   /  flow "Outcome[e]/*Received*treatment*for AE" style(column)=[cellwidth=0.9in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.9in   just=left  borderbottomcolor=black borderbottomwidth=2];



    /*  break after _page / _page;*/

  compute before _page_ / style={bordertopcolor=black bordertopwidth=1 font_face='Arial' font_size=9pt just=left};

    *** THEAD required to get overline ***;
  endcomp;


  *** This COMPUTE BEFORE block is required to add the skip prior to the first data row ***;

  compute after var4;
    line ' ';
  endcomp;


  compute after _page_ / style={bordertopcolor=black bordertopwidth=1 font_face='Arial' font_size=9pt just=left}; 

  	line j=l "[a] Normal = normal renal function; Severe = severe renal impairment.";
	line j=l "[b] (A) = study part A; (B) = study part B. On-trt = between first dose in that study part and up to and including 30 days post-last dose in that study part.";
	line j=l "[c] DNC = Dose not changed;  DR = Dose reduced; DINT = Drug interrupted; DPC = Drug permanently discontinued; NA = Not Applicable.";
	line j=l "[d] As assessed by the investigator.";
	line j=l "[e] RECOVRD = Recovered / Resolved; RECVRNG = Recovering / Resolving; RWS = Recovered / Resolved with sequelae; NRNR = Not recovered / Not resolved; F = Fatal." ;
	line j=l "MedDRA version: 19.1; NRNR = Not recovered / Not resolved; F = Fatal." ;
	line j=l "CTCAE = Common Terminology Criteria for Adverse Events (version 4.0)." ;
  
   endcomp;
run;




