



proc   datasets   library   =  work    kill;
quit;

*** Population Counts;
proc sql noprint;
	select count(distinct usubjid) into: tot  from  adam.adsl where SAFFL = "Y";
	select count(distinct usubjid) into: Trt1 from  adam.adsl where SAFFL = "Y" and group01  ="Normal";
	select count(distinct usubjid) into: Trt2 from  adam.adsl where SAFFL = "Y" and group01  ="Severe";
	select count(distinct usubjid) into: Trt3 from  adam.adsl where group01 = "Severe" & partbfl = "Y";  /*[1]*/
quit;

%put &tot &Trt1 &Trt2 &Trt3;

data ae1;
	set adam.ae;

	if (SAFFL eq "Y" and (TRTEMAFL = "Y" or TRTEMBFL = "Y") and  (partafl = 'Y' or partbfl = 'Y'));

	if missing(aedecod) then aedecod = "UNCODED";
	if TRTEMAFL = 'Y' then phaseN = 1;
	if TRTEMBFL = 'Y' then phaseN = 2;

	output;
	group01 = "Total";
	output;
    
	*to get the grand total of part a & b;
	group01 = 'Total_';
	phasen = 3;
	output;

	Format group01 $40. ;
run;

/*A subject may be counted once only per Period  total but may be counted in each of the first two columns.*/
proc sort data = ae1 out = subnr nodupkey;
	by USUBJID phasen group01;
run;

/*Count Subjects with any AE*/
proc freq data = subnr noprint;
	tables phasen * group01/ out = subnr_fr;
run;


proc sort data = ae1 out = aedecod nodupkey;
	by USUBJID phasen group01 AEDECOD;
run;

data aedecod;
	set aedecod;
	by USUBJID phasen group01  AEDECOD;
run;

proc sort data = aedecod;
	by  AEDECOD;
run;

/*Count prefered term*/
proc freq data = aedecod noprint;
	by  AEDECOD;
	tables phasen * group01/ out = aedecod_fr;
run;

/*Combine the freq datasets*/
data all;
	set  subnr_fr  aedecod_fr(in=a);
	If phasen = 2 and group01 = "Total" then delete ;
	If a then do ;
		if PERCENT <= 10 then delete ;
	end; 
run;

proc sort data = all;
	by phasen group01; 
run;

data all_tot;
	set all;

	if ^missing(count) then
		do;
			if phasen = 1 and group01 = "Normal" then values = put(count,5.)||" ("||put((count/&Trt1*100),5.1)||")";
			if phasen = 1 and group01 = "Severe" then values = put(count,5.)||" ("||put((count/&Trt2*100),5.1)||")";
			if group01 = "Total" then values = put(count,5.)||" ("||put((count/&tot*100),5.1)||")";
			if phasen = 2 and group01 = "Severe" then values = put(count,5.)||" ("||put((count/&Trt3*100),5.1)||")";  
			if phasen = 3 then values = put(count,5.)||" ("||put((count/&tot*100),5.1)||")";
		end;

		If phasen = 2  then group01 = "Severe_b" ;  
run;

proc sort data = all_tot;
	by  AEDECOD phasen;
run;

proc transpose data = all_tot out = all_tr;
	by  AEDECOD phasen;
	var values;
	id group01;
	idlabel group01;
run;

data all_tr;
	set all_tr;

	if missing(AEDECOD) then
		DO
		AESOC = "Subjects with any AE";
			AEDECOD = "Subjects with any AE";

		end;
	

	if missing(AEDECOD) then
		AEDECOD = aesoc;
run;

data phase1 phase2 total_all ;
	set all_tr;

	if phasen = 1 then output phase1;
	if phasen = 2 then output phase2;
    if phasen = 3 then output total_all;

proc sort nodupkey data = phase1;
	by  aedecod;

proc sort nodupkey data = phase2;
	by  aedecod;
run;

proc sort nodupkey data = total_all;
	by  aedecod;
run;

%let lindent1 = %str(^R/RTF'\li340'); /**one tab**/

data final;
	merge phase1(drop = TOTAL_ severe_b) phase2(keep  = aesoc aedecod severe_b) total_all(keep= aesoc aedecod total_) ;
	by  aedecod;

	if normal ="" then normal = "0";  
	if severe_b = "" then severe_b = "0";  
	if TOTAL="" then TOTAL = "0";
	if severe ="" then severe = "0";
	if TOTAL_ = '' then TOTAL_ = '0';
	if aedecod = "Subjects with any AE" then  sort =1 ; 
	else sort = 2 ;
Proc sort ; by sort  aedecod;
 
run;

Data final;
   set final  end = eof;
  by sort aedecod; 

  retain _page 1 _count 1;
   _count+1;
  if _count > 10 then do;
  _page + 1;
  _count = +1;
  end;

  if eof then  call symputx('totpages',_page);

  space1 = " " ;
  space2 = " " ;
  
proc sort;
   by _page  sort aedecod;
run;

%let span=%str(^R/RTF'\trowd\trleft\trql\brdrb\brdrs\sl-0 ');

ods listing close;


options orientation=portrait topmargin=1.2in bottommargin=1in leftmargin=1in rightmargin=1in nodate nobyline; /*Adjusting the paper*/
ods rtf file= "&root./Outputs/Tables/AET2.rtf" /*bodytitle*/;
title1    justify = center   height = 11pt  font = 'Arial' "XYZ";
title2    justify = center   height = 11pt  font = 'Arial' "Table 2 Adverse Events,  most common (frequency of >10% in Total group) (Safety analysis set)";


proc report data=final  nowindows headline headskip split='*'
	style(report)=[background=white rules=NONE frame=void bordertopwidth=2]
	style(header)=[vjust = middle background=white font_face='Arial' font_size=9pt ]
	style(column)=[cellheight=0.5 in];

  By _page ;

  column _page  sort  aedecod    ("Number (%) of subjects [a]&span."  ("Part A&span." normal severe TOTAL) space1 
                                      ("Part B&span." severe_b) space2  ("Parts A and B&span." TOTAL_));

    define _page / order noprint;
	define sort / order noprint;

  	define aedecod   /  flow  "Preferred term" flow style(column)=[cellwidth=2in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=2in   just=left  borderbottomcolor=black borderbottomwidth=2];
 
    define normal   /  flow  "Normal renal*function*(N=%left(&Trt1.))" flow style(column)=[cellwidth=0.6in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.6in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define severe   /  flow "Severe renal*impairment*(N=%left(&Trt2.))" style(column)=[cellwidth=0.8in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.8in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define TOTAL   /   flow "Total*(N=%left(&TOT.))" style(column)=[cellwidth=0.6in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.6in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define space1   /   flow " " style(column)=[cellwidth=0.2in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.2in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define severe_b   /  flow "Severe renal*impairment*(N=%left(&Trt3.))" style(column)=[cellwidth=0.8in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.8in   just=left  borderbottomcolor=black borderbottomwidth=2];

	 define space2   /   flow " " style(column)=[cellwidth=0.2in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.2in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define TOTAL_   /  flow "Total*(N=%left(&TOT.))" style(column)=[cellwidth=0.8in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.8in   just=left  borderbottomcolor=black borderbottomwidth=2];



    /*  break after _page / _page;*/

  compute before _page_ / style={bordertopcolor=black bordertopwidth=1 font_face='Arial' font_size=9pt just=left};

    *** THEAD required to get overline ***;
  endcomp;


  *** This COMPUTE BEFORE block is required to add the skip prior to the first data row ***;

  compute after sort;
    line ' ';
  endcomp;


  compute after _page_ / style={bordertopcolor=black bordertopwidth=1 font_face='Arial' font_size=9pt just=left}; 

  	line j=l "[a] Number (%) of subjects with AEs.";
	line j=l "AE counted for Part A if onset was after first dose of Dummy in Part A and up to and including 30 days post-last dose in Part A (and prior to first dose of Dummy in either Part B or continued access post-Part A ).";
	line j=l "AE counted for Part B if onset was after first dose of Dummy in Part B and up to and including 30 days post-last dose in Part B (and prior to first dose of Dummy in continued access post-Part B).";
	line j=l "A subject can have one or more preferred terms reported under a given system organ class.";
	line j=l "Most common is defined as a total frequency of >10%.";
	line j=l "MedDRA version 19.1";
  
   endcomp;
run;

