
/* Clean the lib */  
proc datasets lib = work kill;quit;

*=============================================================================*;

**---------------------------------------------------------------------------**;
**                Table Patient disposition (All patients)                   **;
**---------------------------------------------------------------------------**;

/* Retrieve data from AdaM and create - a var TRTN for the different Part and Group - a var PHASEN for the different Part */
data dd0 ;
	set adam.adsl;

	if PARTAFL="Y" then do;
		select(GROUP01);
		when ("Normal") TRTN = 1 ;
		when ("Severe") TRTN = 2 ;
		otherwise;
	end;
	end;
	if ^missing(TRTN) then do;
		output;
	end;
	
	if ^missing(TRTN) then do;
		TRTN = 3; *Total;
		output; 
	end;
	if PARTBFL="Y" and GROUP01 = "Severe" then do;
		TRTN=4;
		output;
	end;
run;
data dd0 ;
	set dd0;
	if TRTN IN (1,2) then PHASEN = 1;
	if TRTN IN (3) then PHASEN = 2;
	if TRTN IN (4) then PHASEN = 3;
run;

data dd1 ;
    length cat1 cat2 $200. ords 8.;
	set dd0;

	/* The definition is "subjects that are enrolled in the study and meet the requirements for inclusion in the study (which includes consent received) */	
	if  enrlfl = "Y"  then do; 
		cat1= "Subjects assigned to treatment";
		cat2= "Subjects assigned to treatment";
		ords = 1;
	end;
		output;
	
	if pkfl = "Y" then do;
		cat1= "Subjects included in PK analysis set";
		cat2= "Subjects included in PK analysis set";
		ords = 2;
		output;
	end;

	if pkfl = "N" then do;
		cat1= "Subjects excluded from PK analysis set [a]";
		cat2= "Subjects excluded from PK analysis set [a]";
		ords = 3;
		output;
	end;

	if pkfl = "N" then do;
		cat1= "Subjects excluded from PK analysis set [a]";
		cat2= pkxl;
		ords = 4;
		output;
	end;

	if saffl = "Y"  then do;
		cat1= "Subjects included in safety analysis set";
		cat2= "Subjects included in safety analysis set";
		ords = 5;
		output;
	end;

	if saffl = "N"  then do;
		cat1= "Subjects excluded from safety analysis set";
		cat2 = safxl;
		ords = 6;
		output;
	end;
	
	keep usubjid cat1 cat2 ords armcd trtn phasen;
run;

proc sort data = dd1 nodupkey;
	by usubjid cat1 cat2 ords armcd trtn phasen;
run;

/* Calculate the count and percentage by categories 1,2 and by trtn and phasen */
proc freq data = dd1 noprint;
	tables cat1*cat2*ords*trtn*phasen/ nopercent out = outcat4;
	where ^missing(cat1);
run;
proc sort data = outcat4;by ords cat1 cat2 phasen trtn ;run;

data all;
   set outcat4;
   
run;
proc sort data = all nodupkey;by  ords cat1 cat2 phasen trtn count;run;

/* Transpose the information in line (trt and phase) in column */
proc transpose data = all out = all_tr prefix=C;
  var count;
  id TRTN ;
  by ords cat1 cat2 ;
run;

/***Creating a template***/

data template;
  length cat1 cat2 $200. ords 8.;
  cat1 = "Subjects assigned to treatment";
  cat2 = "Subjects assigned to treatment";
  ords = 1;
  output;
  
  cat1 = "Subjects included in PK analysis set";
  cat2 = "Subjects included in PK analysis set";
  ords = 2;
  output;
  cat1 = "Subjects excluded from PK analysis set [a]";
  cat2 = "Subjects excluded from PK analysis set [a]";
  ords = 3;
  output;
  cat1 = "Subjects excluded from PK analysis set [a]";
  cat2 = "No measurable PK concentration";
  ords = 4;
  output;
  cat1 = "Subjects included in safety analysis set";
  cat2 = "Subjects included in safety analysis set";
  ords = 5;
  output;
  cat1 = "Subjects excluded from safety analysis set";
  cat2 = "Subjects excluded from safety analysis set";
  ords = 6;
  output;
  cat1 = "Subjects excluded from safety analysis set";
  cat2 = "Did not receive treatment";
  ords = 7;
  output;

run;
proc sort data = template ; by ords cat1 ;run;

data dd2;
  merge all_tr(in=a) template(in=b);
  by ords cat1 cat2;
 
run;

/* Replace the missing by 0 and calculate the column total of the Part A */
data dd3;
	Set dd2;
   	if missing(C1) then C1 = 0; 
   	if missing(C2) then C2 = 0;
  	if missing(C3) then C3 = 0;
	if missing(C4) then C4 = 0;
Run;

proc sort data = dd3;
  by ords CAT1 cat2;
run;

%let lindent1 = %str(^R/RTF'\li340');

data final ;
	Set dd3 ;
	if ords in (4 7) then cat2 = "&lindent1." || Cat2 ;
	if ords = 1 then grp = 1 ;
	if ords in (2 3 4) then grp = 2 ;
	if ords in (5 6 7) then grp = 3 ;	
run ;


Data final;
   set final  end = eof;

  retain _page 1 _count 1;
   _count+1;
  if _count > 15 then do;
  _page + 1;
  _count = +1;
  end;

  if eof then  call symputx('totpages',_page);

  
proc sort;
   by _page ords ;
run;

%let span=%str(^R/RTF'\trowd\trleft\trql\brdrb\brdrs\sl-0 ');

ods listing close;


options orientation=portrait topmargin=1.2in bottommargin=1in leftmargin=1in rightmargin=1in nodate nobyline; /*Adjusting the paper*/
ods rtf file= "&root./Outputs/Tables/DMT1.rtf" /*bodytitle*/;
title1    justify = center   height = 11pt  font = 'Arial' "XYZ";
title2    justify = center   height = 11pt  font = 'Arial' "Table 5 Summary of analysis sets (All subjects)";


proc report data=final  nowindows headline headskip split='*'
	style(report)=[background=white rules=NONE frame=void bordertopwidth=2]
	style(header)=[vjust = middle background=white font_face='Arial' font_size=9pt ]
	style(column)=[cellheight=0.4 in];

  By _page ;

  column _page  ORDS grp CAT2   ("Number (%) of subjects [a]&span."  ("Part A&span." C1 C2 C3)  
                                      ("Part B&span." C4) );

    define _page / order noprint;
	define ORDS / order noprint;
	define GRP / order noprint;


  	define cat2   /  flow  " " flow style(column)=[cellwidth=2.5in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=2.5in   just=left  borderbottomcolor=black borderbottomwidth=2];
 
    define C1   /  flow  "Normal renal*function" flow style(column)=[cellwidth=0.8in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.8in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define C2   /  flow "Severe renal*impairment" style(column)=[cellwidth=0.8in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.8in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define C3   /   flow "Total" style(column)=[cellwidth=0.6in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.6in   just=left  borderbottomcolor=black borderbottomwidth=2];


    define C4   /  flow "Severe renal*impairment" style(column)=[cellwidth=0.8in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=0.8in   just=left  borderbottomcolor=black borderbottomwidth=2];


    /*  break after _page / _page;*/

  compute before _page_ / style={bordertopcolor=black bordertopwidth=1 font_face='Arial' font_size=9pt just=left};

    *** THEAD required to get overline ***;
  endcomp;


  *** This COMPUTE BEFORE block is required to add the skip prior to the first data row ***;

  compute after grp;
    line ' ';
  endcomp;


  compute after _page_ / style={bordertopcolor=black bordertopwidth=1 font_face='Arial' font_size=9pt just=left}; 

  	line j=l "[a] Subjects could have been excluded for more than 1 reason.";
	
  
   endcomp;
run;






