
/*******************************************
    Deleting data sets from work library 
*******************************************/

Proc Datasets library = work memtype = data nolist kill ;run ; quit ;
 

proc sql noprint;
    select count(distinct USUBJID) into: A1 from adam.adsl  where compress(upcase(saffl)) = "Y" ;
quit;

%put &A1 ; 

data  eff1;
  set adam.ex;
  where partbfl="Y" & Saffl  ="Y" and extrt = "Dummy";

  proc sort ; by GROUP01  ;

Run;  

proc means data = eff1 noprint;
  by GROUP01  ;
  var ADURN;
  output out = eff_mn
    mean   = mean1
    std    = std1
	median = median1
    min    = min1
    max    = max1
	sum	   = sum1
    ;
run;

data eff_mnc;
  set  eff_mn ;
  length _1 - _6 $100;
  _1 = put(round(mean1,0.1),8.1);
  _2 = put(round(std1,0.1),8.1);
  _3 = put(round(median1,0.1),8.1);
  _4 = put(min1,8.0);
  _5 = put(max1,8.0);
  _6 = put(round((sum1/365.25),0.1),8.1);

run;

proc transpose data = eff_mnc out = eff_tr ;
  id GROUP01;
  var _1 _2 _3 _4 _5 _6  ;
run;

proc format;
  value $stat
    "_1" = "Mean "
    "_2" = "SD"
    "_3" = "Median"
    "_4" = "Min"
    "_5" = "Max  "
	"_6" = "Total treatment years"
  ;
run;

data final;
length col1 COL2 $200.;
   set eff_tr ;
col1 = "Total treatment duration (days) [a]";
col2 = compress(put(_name_,stat.));
run;

Data final;
   set final   end = eof;

  retain _page 1 _count 1;
   _count+1;
  if _count > 15 then do;
  _page + 1;
  _count = +1;
  end;

  if eof then  call symputx('totpages',_page);
  
proc sort;
   by _page ;
run;

%let span=%str(^R/RTF'\trowd\trleft\trql\brdrb\brdrs\sl-0 ');

ods listing close;


options orientation=portrait topmargin=1.2in bottommargin=1in leftmargin=1in rightmargin=1in nodate nobyline; /*Adjusting the paper*/
ods rtf file= "&root./Outputs/Tables/EXT1.rtf" /*bodytitle*/;
title1    justify = center   height = 11pt  font = 'Arial' "XYZ";
title2    justify = center   height = 11pt  font = 'Arial' "Table 4 Duration of dummy exposure (Safety analysis set)";


proc report data=final  nowindows headline headskip split='*'
	style(report)=[background=white rules=NONE frame=void bordertopwidth=2]
	style(header)=[vjust = middle background=white font_face='Arial' font_size=9pt ]
	style(column)=[cellheight=0.4 in];

  By _page ;

  column _page  COL1 COL2   ("Part B &Span." severe);

    define _page / order noprint;

  	define COL1   /ORDER  flow  "Treatment duration (months)" flow style(column)=[cellwidth=2in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=2in   just=left  borderbottomcolor=black borderbottomwidth=2];
 
    define COL2   /  flow  " " flow style(column)=[cellwidth=2in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=2in   just=left  borderbottomcolor=black borderbottomwidth=2];

    define severe   /  flow "Severe renal*impairment*(N=%left(&A1.))" style(column)=[cellwidth=1.5in   just=left font_face='Arial' font_size=9pt]
								style(header)=[cellwidth=1.5in   just=left  borderbottomcolor=black borderbottomwidth=2];


    /*  break after _page / _page;*/

  compute before _page_ / style={bordertopcolor=black bordertopwidth=1 font_face='Arial' font_size=9pt just=left};

    *** THEAD required to get overline ***;
  endcomp;


  *** This COMPUTE BEFORE block is required to add the skip prior to the first data row ***;


  compute after _page_ / style={bordertopcolor=black bordertopwidth=1 font_face='Arial' font_size=9pt just=left}; 

	line j=l "[a] Total treatment duration = (last dose date - first dose date +1).";
  
   endcomp;
run;



